/*
 * DCAP - Direct CAPture
 * Copyright (C) 2020 Oliver Kirsebom
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

#include <DCAP/LogDerivDiff.h>

using namespace std;
using namespace ORM;
using namespace DCAP;


LogDerivDiff::LogDerivDiff(shared_ptr<ParticleChannel>& channel, double energy, double radius) 
    : channel(channel), E(energy), r(radius) {
    double W = channel->whittakerFunction(E);
    double dWdr = channel->whittakerFunctionDerivative(E);
    lhs = 1./(W/r) * (1./r*dWdr - W/(r*r));
}

double LogDerivDiff::operator() (double *x, double *p) {
    double V0 = x[0]; //potential depth in keV
    double j = channel->regSphericalBesselFunction(E+V0);
    double djdr = channel->regSphericalBesselFunctionDerivative(E+V0);
    double rhs = 1./j * djdr;
    return rhs - lhs;
}
